@@ -139,7 +139,6 @@ class Match:
         Optional[tuple[str, int]]
             The best string and its score found, or None if no good match was found.
         """
-
         kwargs: RatioKwargs = {
             "scorer": self.scorer,
             "score": score,
@@ -150,20 +149,23 @@ class Match:
             "include_partial": self.include_partial,
         }
 
+        ratio = Ratio(**kwargs)
+
         matches = sorted(
-            [
-                (s, Ratio(**kwargs).ratio(string, s))
-                for s in string_list
-                if Ratio(**kwargs).ratio(string, s) >= score
-            ],
+            # We only add the entry to the list if the ratio is above the cutoff score.
+            [(s, r) for s in string_list if (r := ratio.ratio(string, s)) >= score],
             key=lambda x: (
+                # We first sort the list by the score.
                 x[1],
+                # Then we sort the list by the character difference.
                 -abs(
                     len(string) - len(x[0])
                     if all(isinstance(c, str) for c in [x[0], string])
                     else float("-inf")
                 ),
+                # And lastly we sort it by the length of the string.
                 len(x[0]) if isinstance(x[0], str) else float("-inf"),
+                # If all of these are tied, the list is sorted by order of how they appear in the original list.
             ),
             reverse=True,
         )
@@ -200,11 +202,12 @@ class Match:
         list[str]
             All of the matches found.
         """
-        # we return every match found if the limit is 0 or less
+        # We return every match found if the limit is 0 or less.
         if limit is not None and limit < 1:
             limit = None
 
         return [
+            # We only return the string without the score.
             m[0]
             for m in self.get_best_matches_with_ratio(
                 string, string_list, score=score, limit=limit
@@ -238,7 +241,6 @@ class Match:
         list[tuple[str, int]]
             All of the matches found.
         """
-
         kwargs: RatioKwargs = {
             "scorer": self.scorer,
             "score": score,
@@ -253,12 +255,11 @@ class Match:
         if limit is not None and limit < 1:
             limit = None
 
-        matches = sorted(
-            [
-                (s, Ratio(**kwargs).ratio(string, s))
-                for s in string_list
-                if Ratio(**kwargs).ratio(string, s) >= score
-            ],
+        ratio = Ratio(**kwargs)
+
+        # This is the same sorting as in the get_best_match_with_ratio function.
+        return sorted(
+            [(s, r) for s in string_list if (r := ratio.ratio(string, s)) >= score],
             key=lambda x: (
                 x[1],
                 -abs(
@@ -269,6 +270,4 @@ class Match:
                 len(x[0]) if isinstance(x[0], str) else float("-inf"),
             ),
             reverse=True,
-        )
-
-        return matches[:limit]
+        )[:limit]
